activeDateFormat property
- @Input.new()
getter/setter pair
The DateFormat used to format dates when the input is active.
Defaults to yMd, e.g. "7/31/15".
Implementation
@Input()
DateFormat activeDateFormat = DateFormat.yMd();
The DateFormat used to format dates when the input is active.
Defaults to yMd, e.g. "7/31/15".
@Input()
DateFormat activeDateFormat = DateFormat.yMd();