allowParentMultiSelection property
Whether the widgets supports the selection of non-leaf nodes.
When false, and the widget should toggle expansion when a non-leaf
node is clicked. When true the widget should select non-leaf nodes
when clicked and only toggle expansion when the expansion icon is clicked.
Implementation
bool get allowParentMultiSelection => true;